pub struct Classes { /* private fields */ }Expand description
How many decisions were made on what.
The class histogram of spec/stats/09-measurement.md section 9.5. For a whole suite, the
fraction of the planner’s decisions that were exact, certified, estimated or unknown, which is
the direct measurement of whether the statistics layer is doing its job. It is more diagnostic
than q-error for the first several milestones, because early on the estimates are bad for the
boring reason that there are none.
Implementations